@@ -45,7 +45,7 @@ INVALID_ID_STRINGS = (
 	"None", "empty",
 	"01010101-0101-0101-0101-010101010101",
 	"00020003-0004-0005-0006-000700080009",
-	"00000000",
+	"0000000", "00000000",
 )
 
 class Singleton(type):
